<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>FlipVertical</name>
    <message>
        <location filename="../FlipVerticalInit.js" line="+2"/>
        <source>Flip Verti&amp;cal</source>
        <translation>Odbij p&amp;ionowo</translation>
    </message>
</context>
</TS>
